@@ -601,7 +601,7 @@ int main(int argc, char *argv[])
 		gnome_druid_append_page(GNOME_DRUID(druid), GNOME_DRUID_PAGE(page));
 
 	page = Service(8, _("Telnet"), 23, 
-		_("Allow incoming telnet accesss. This allows access to the "
+		_("Allow incoming telnet access. This allows access to the "
 		"command line shell of the machine from outside, if you "
 		"have a username and password. It is not encrypted and can "
 		"therefore be spied upon. If possible avoid enabling this."),
