@@ -54,7 +54,10 @@ char **getNetworkDevices(int *len) {
 		qsort((void *)ret, num, sizeof(char *), 
 		      (int (*)(const void *, const void *))strcmp);
 	}
-	return ret;
+	if (!num)
+	  return NULL;
+	else
+	  return ret;
 }
 
 void helpCallback(newtComponent co, void * tag) {
@@ -151,7 +154,7 @@ void helpCallback(newtComponent co, void * tag) {
 			     "\n"
 			     "     * DHCP -- This allows DHCP queries and replies,\n"
 			     "       and allows any network interfaces that use\n"
-			     "       DHCP determine their IP address. DHCP is\n"
+			     "       DHCP to determine their IP address. DHCP is\n"
 			     "       normally enabled.\n"
 			     "     * SSH -- Secure Shell (SSH) is a protocol for\n"
 			     "       logging into and executing commands on remote\n"
